@@ -313,7 +313,7 @@ $(document).ready(function() {
     }
     setTimeout(updateWidgets, 1000);
 
-    // Solid initialization, usage:
+    // Solid initialization, usage::
     //
     //      $(document).bind('yourlabsWidgetReady', function() {
     //          $('.your.autocomplete-light-widget').live('initialize', function() {
@@ -331,7 +331,13 @@ $(document).ready(function() {
     $(document).bind('DOMNodeInserted', function(e) {
         var widget = $(e.target).find('.autocomplete-light-widget');
 
-        if (!widget.length) return;
+        if (!widget.length) {
+            widget = $(e.target).is('.autocomplete-light-widget') ? $(e.target) : false;
+
+            if (!widget) {
+                return;
+            }
+        }
 
         widget.trigger('initialize');
     });
